# wiliot-network-utils #

<!-- Description -->
wiliot-network-utils is a Python package containing scripts and utilities for maintaining and managing Wiliot network devices efficiently.

## Installing wiliot-network-utils
````commandline
pip install wiliot-network-utils
````

## Using wiliot-network-utils
### wlt-brg-ota-location
For more info, run:
````commandline
wlt-brg-ota-location -h
````

